"""
test
"""

from .config import GENOME_VERSION
from .main import rnpfind
